#
# Conditional build
%bcond_without	openmp	# OpenMP support
%bcond_without	tcl	# Tcl/Tk support
%bcond_without	tests	# do not run "make check"
%bcond_without	docs	# do not build documentation
#
# NOTE:
# - /etc/localtime must be present for tests to work
#
# TODO:
# - script for rpm to autoprovides/autorequires R internals
#
%include	/usr/lib/rpm/macros.perl
Summary:	A language for data analysis and graphics
Summary(pl.UTF-8):	Język do analizy danych oraz grafiki
Name:		R
Version:	3.6.1
Release:	1
License:	mixed (distributable), mostly GPL v2+
Group:		Development/Languages
# CRAN master site: ftp://cran.r-project.org/pub/R/src/
Source0:	ftp://stat.ethz.ch/R-CRAN/src/base/R-3/%{name}-%{version}.tar.gz
# Source0-md5:	f5003472d58a3d3765a1c537fdae71d5
Source1:	%{name}.desktop
Source2:	%{name}.xpm
URL:		http://www.r-project.org/
# yes, it is, or tests will fail
BuildRequires:	/etc/localtime
BuildRequires:	autoconf >= 2.69
BuildRequires:	automake
BuildRequires:	blas-devel >= 3.2.2-2
BuildRequires:	bzip2-devel >= 1.0.6
BuildRequires:	cairo-devel >= 1.6
BuildRequires:	curl-devel >= 7.28.0
BuildRequires:	gcc-fortran
BuildRequires:	gettext-tools >= 0.16.1
BuildRequires:	lapack-devel >= 3.2.2-2
%{?with_openmp:BuildRequires:	libgomp-devel}
BuildRequires:	libicu-devel
BuildRequires:	libjpeg-devel >= 6b
BuildRequires:	libpng-devel >= 1.2.7
BuildRequires:	libstdc++-devel
BuildRequires:	libtiff-devel
BuildRequires:	libtool >= 2:2.0
BuildRequires:	libxml2-devel >= 2.6.26
BuildRequires:	pango-devel
BuildRequires:	pcre-devel >= 8.32
# actually not used
#BuildRequires:	pcre2-8-devel
BuildRequires:	perl-base >= 1:5.6
BuildRequires:	pkgconfig
BuildRequires:	readline-devel
BuildRequires:	rpm-perlprov
%if %{with tcl}
BuildRequires:	tcl-devel >= 8.4
BuildRequires:	tk-devel >= 8.4
%endif
BuildRequires:	tre-devel
%if %{with docs}
BuildRequires:	tetex-dvips
BuildRequires:	tetex-latex
BuildRequires:	tetex-pdftex
BuildRequires:	texinfo-texi2dvi >= 4.7
%endif
BuildRequires:	xorg-lib-libX11-devel
BuildRequires:	xorg-lib-libXmu-devel
BuildRequires:	xorg-lib-libXt-devel
BuildRequires:	xz-devel >= 5.0.3
BuildRequires:	zip
BuildRequires:	zlib-devel >= 1.2.3
#Requires:	lpr
Requires(post):	perl-base
Requires(post):	textutils
Requires:	blas >= 3.2.2-2
Requires:	bzip2 >= 1.0.6
Requires:	curl-libs >= 7.28.0
Requires:	pcre >= 8.32
Requires:	xz-libs >= 5.0.3
Requires:	zlib >= 1.2.3
Suggests:	rkward
Obsoletes:	R-base
Obsoletes:	R-contrib
Obsoletes:	R-recommended
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
A system for statistical computation and graphics. R consists of a
language plus a run-time environment with graphics, a debugger, access
to certain system functions, and the ability to run programs stored in
script files.

The design of R has been heavily influenced by two existing languages:
Becker, Chambers & Wilks' S and Sussman's Scheme. Whereas the
resulting language is very similar in appearance to S, the underlying
implementation and semantics are derived from Scheme.

%description -l pl.UTF-8
System do obliczeń statystycznych i grafiki. R składa się z języka
oraz środowiska uruchomieniowego z grafiką, debuggerem, dostępem do
niektórych funkcji systemowych oraz możliwością uruchamiania programów
zapisanych w skryptach.

Język R był zainspirowany dwoma istniejącymi językami: S (Beckera,
Chambersa i Wilksa) oraz Scheme (Sussmana). R jest podobny do S, ale
implementacja i semantyka wywodzi się ze Scheme.

%package java-tools
Summary:	R Java tools
Summary(pl.UTF-8):	Narzędzia R w Javie
Group:		Development/Tools
Requires:	%{name} = %{version}-%{release}

%description java-tools
R Java classes.

%description java-tools -l pl.UTF-8
Narzędzia R w Javie.

%prep
%setup -q

%build
%{__aclocal} -I m4
%{__autoconf}
install -d build
cd build
../%configure \
	F77=gfortran \
	FC=gfortran \
	--enable-R-shlib \
	--enable-largefile \
	%{!?with_openmp:--disable-openmp} \
	--with-internal-tzcode \
	--with-ICU \
	--with-blas \
	--with-cairo \
	--with-jpeglib \
	--with-lapack \
	--with-libpng \
	--with-readline \
	--with-recommended-packages \
	--with-system-tre \
%if %{with tcl}
	--with-tcltk \
	--with-tcl-config=/usr/lib/tclConfig.sh \
	--with-tk-config=/usr/lib/tkConfig.sh \
%else
	--without-tcltk \
%endif
	--with-x

%{__make} -j1

%if %{with tests}
%{__make} check
%endif

%if %{with docs}
%{__make} docs pdf info
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_bindir},%{_mandir}/man1,%{_libdir}/R,%{_includedir},%{_desktopdir},%{_pixmapsdir}}

%{__make} -C build -j1 install \
	DESTDIR=$RPM_BUILD_ROOT

install %{SOURCE1} $RPM_BUILD_ROOT%{_desktopdir}
install %{SOURCE2} $RPM_BUILD_ROOT%{_pixmapsdir}

ln -sf %{_libdir}/R/lib/libR.so $RPM_BUILD_ROOT%{_libdir}

%{__mv} $RPM_BUILD_ROOT%{_libdir}/%{name}/include $RPM_BUILD_ROOT%{_includedir}/R
ln -sf %{_includedir}/R $RPM_BUILD_ROOT%{_libdir}/R/include

gen_lang() {
	dir="$1"
	for d in $RPM_BUILD_ROOT${dir}/* ; do
		bd=$(basename $d)
		lang="${bd%@*}"
		echo "%lang($lang) ${dir}/${bd}"
	done
}

for moddir in $RPM_BUILD_ROOT%{_libdir}/R/library/* ; do
	module=$(basename $moddir)
	echo "%dir %{_libdir}/R/library/${module}"
	if [ "$module" = "translations" ]; then
		for f in $moddir/* ; do
			bf=$(basename $f)
			case "$bf" in
			  DESCRIPTION|en|en@quot)
				echo "%{_libdir}/R/library/${module}/${bf}"
				;;
			  *)
				echo "%lang(${bf}) %{_libdir}/R/library/${module}/${bf}"
				;;
			esac
		done
	else
		for f in $moddir/* ; do
			bf=$(basename $f)
			case "$bf" in
			  po)
				echo "%dir %{_libdir}/R/library/${module}/po"
				gen_lang %{_libdir}/R/library/${module}/po
				;;
			  libs)
				echo "%dir %{_libdir}/R/library/${module}/libs"
				echo "%attr(755,root,root) %{_libdir}/R/library/${module}/libs/*.so"
				;;
			  *)
				echo "%{_libdir}/R/library/${module}/${bf}"
				;;
			esac
		done
	fi
done > R.files

# just GPL
%{__rm} $RPM_BUILD_ROOT%{_libdir}/R/doc/COPYING
# packaged as %doc
%{__rm} $RPM_BUILD_ROOT%{_libdir}/R/doc/{AUTHORS,COPYRIGHTS,FAQ,NEWS.rds,THANKS}
%if %{with docs}
# pdf version of NEWS
%{__rm} $RPM_BUILD_ROOT%{_libdir}/R/doc/NEWS.pdf
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files -f R.files
%defattr(644,root,root,755)
%doc README doc/{AUTHORS,COPYRIGHTS,FAQ,NEWS,NEWS.[012],RESOURCES,THANKS}
%attr(755,root,root) %{_bindir}/R
%attr(755,root,root) %{_bindir}/Rscript
%dir %{_libdir}/R
%dir %{_libdir}/R/lib
%attr(755,root,root) %{_libdir}/R/lib/libR.so
%attr(755,root,root) %{_libdir}/libR.so
%{_libdir}/R/COPYING
%{_libdir}/R/SVN-REVISION
%attr(755,root,root) %{_libdir}/R/bin
%exclude %{_libdir}/R/bin/javareconf
# %{_libdir}/R/doc %except %{_libdir}/R/doc/html/{packages.html,search/index.txt}
%dir %{_libdir}/R/doc
%{_libdir}/R/doc/[KRm]*
%{_libdir}/R/doc/BioC_mirrors.csv
%{_libdir}/R/doc/CRAN_mirrors.csv
%{_libdir}/R/doc/NEWS*
%dir %{_libdir}/R/doc/html
%{_libdir}/R/doc/html/Rlogo.svg
%{_libdir}/R/doc/html/*.css
%{_libdir}/R/doc/html/[NRSa-lr-u]*.html
%{_libdir}/R/doc/html/packages-head*.html
%{_libdir}/R/doc/html/favicon.ico
%{_libdir}/R/doc/html/*.jpg
%ghost %{_libdir}/R/doc/html/packages.html
%{_libdir}/R/etc
%{_libdir}/R/include
%dir %{_libdir}/R/library
# library files list is autogenerated (see R.files above)
%attr(755,root,root) %{_libdir}/R/modules
%dir %{_libdir}/R/share
%{_libdir}/R/share/R
%{_libdir}/R/share/Rd
%{_libdir}/R/share/dictionaries
%{_libdir}/R/share/encodings
%{_libdir}/R/share/licenses
%{_libdir}/R/share/make
%{_libdir}/R/share/sh
%{_libdir}/R/share/texmf
%{_libdir}/R/share/zoneinfo
%{_desktopdir}/R.desktop
%{_pixmapsdir}/R.xpm
%{_includedir}/R
%{_pkgconfigdir}/libR.pc
%{_mandir}/man1/R.1*
%{_mandir}/man1/Rscript*

%files java-tools
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/R/bin/javareconf
%{_libdir}/R/share/java
%changelog
* Fri Oct 25 2019 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/R.git;a=log;h=master

* Fri Oct 25 2019 Jakub Bogusz <qboosh@pld-linux.org> 871a4fa
- updated to 3.6.1

* Thu Oct 17 2019 Arkadiusz Miśkiewicz <arekm@maven.pl> fb2b8ee
- release 3 (by relup.sh)

* Sun Oct 06 2019 Jan Rękorajski <baggins@pld-linux.org> a795657
- rebuild with icu 65.1
- release 2 (by relup.sh)

* Thu May 09 2019 Jakub Bogusz <qboosh@pld-linux.org> 34254ce
- updated to 3.6.0

* Sun Apr 14 2019 Adam Gołębiowski <adamg@pld-linux.org> 7ae9389
- release 2, rebuild against icu 64

* Mon Jan 21 2019 Marcin Krol <hawk@tld-linux.org> 2001c6b
- updated to 3.5.2, note: requires configured /etc/localtime to build

* Fri Mar 16 2018 Jakub Bogusz <qboosh@pld-linux.org> 967c8b5
- updated to 3.4.3

* Sat May 27 2017 Jakub Bogusz <qboosh@pld-linux.org> 6355f66
- updated to 3.4.0

* Thu May 25 2017 Jan Rękorajski <baggins@pld-linux.org> 1cc13d3
- rebuild with lapack 3.7
- release 6 (by relup.sh)

* Sun Apr 23 2017 Jan Rękorajski <baggins@pld-linux.org> 592ade8
- release 5 (by relup.sh)

* Fri Mar 10 2017 Jan Rękorajski <baggins@pld-linux.org> 6b53a0f
- rebuild with icu 58.2
- release 4 (by relup.sh)

* Tue Oct 18 2016 Jan Rękorajski <baggins@pld-linux.org> 46a874c
- rebuild with readline 7.0
- release 3 (by relup.sh)

* Mon May 16 2016 Elan Ruusamäe <glen@delfi.ee> 9d65188
- icu-57.1 rebuild
- release 2 (by relup.sh)

* Mon Apr 18 2016 Jakub Bogusz <qboosh@pld-linux.org> 143480d
- updated to 3.2.5

* Sun Mar 06 2016 Jakub Bogusz <qboosh@pld-linux.org> b61bd14
- updated to 3.2.3

* Wed Nov 18 2015 Jan Rękorajski <baggins@pld-linux.org> 3d2092f
- release 6 (by relup.sh)

* Mon Jun 01 2015 Elan Ruusamäe <glen@delfi.ee> ccff675
- icu rebuild
- release 5 (by relup.sh)

* Mon Mar 09 2015 Jan Rękorajski <baggins@pld-linux.org> 9f0dd5e
- BR /etc/localtime for tests, rel 4

* Mon Mar 09 2015 Jan Rękorajski <baggins@pld-linux.org> 22cdc93
- package internal tzdata, rel 3

* Sun Mar 08 2015 Jan Rękorajski <baggins@pld-linux.org> b8727be
- use internal tzcode, rel 2

